require File.expand_path(File.dirname(__FILE__) + '/helper')

describe 'Tennpipes::Cache - Moneta store' do
  def setup
    @test_key = "val_#{Time.now.to_i}"
  end

  def teardown
    Tennpipes.cache.clear
  end

  class Foo
    def bar; "bar"; end
  end

  it "return nil trying to get a value that doesn't exist" do
    Tennpipes.cache.clear
    assert_equal nil, Tennpipes.cache[@test_key]
  end

  it 'set and get an object with marshal' do
    Tennpipes.cache[@test_key] = Foo.new
    assert_equal "bar", Tennpipes.cache[@test_key].bar
  end

  it 'set and get a nil value' do
    Tennpipes.cache[@test_key] = nil
    assert_equal '', Tennpipes.cache[@test_key].to_s
  end

  it 'set and get a raw value' do
    Tennpipes.cache[@test_key] = 'foo'
    assert_equal 'foo', Tennpipes.cache[@test_key]
  end

  it "set a value that expires" do
    init_time = ( Time.now - 20 )
    Time.stub(:now, init_time) { Tennpipes.cache.store(@test_key, 'test', :expires => 1) }
    Time.stub(:now, init_time + 20) { assert_equal nil, Tennpipes.cache[@test_key] }
  end

  it "be able to cache forever" do
    Tennpipes.cache.store('forever', 'cached', :expires => false)
    2.times { |i| assert_equal 'cached', Tennpipes.cache['forever'] }
  end

  it 'delete a value' do
    Tennpipes.cache[@test_key] = 'test'
    assert_equal 'test', Tennpipes.cache[@test_key]
    Tennpipes.cache.delete(@test_key)
    assert_equal nil, Tennpipes.cache[@test_key]
  end
end
